.\" -*-nroff-*-
.\" ====================================================================
.\"  @Troff-man-file{
.\"     author          = "Nelson H. F. Beebe",
.\"     version         = "1.00",
.\"     date            = "07 April 2001",
.\"     time            = "14:00:12 MDT",
.\"     filename        = "pstojpeg.man",
.\"     address         = "Center for Scientific Computing
.\"                        University of Utah
.\"                        Department of Mathematics, 322 INSCC
.\"                        155 S 1400 E RM 233
.\"                        Salt Lake City, UT 84112-0090
.\"                        USA",
.\"     telephone       = "+1 801 581 5254",
.\"     FAX             = "+1 801 585 1640, +1 801 581 4148",
.\"     URL             = "http://www.math.utah.edu/~beebe",
.\"     checksum        = "30360 312 1141 8289",
.\"     email           = "beebe@math.utah.edu, beebe@acm.org,
.\"                        beebe@computer.org, beebe@ieee.org
.\"                        (Internet)",
.\"     codetable       = "ISO/ASCII",
.\"     keywords        = "JPEG (Joint Photographic Experts Group);
.\"                        portable anymap; portable bitmap;
.\"                        PostScript",
.\"     supported       = "yes",
.\"     docstring       = "This is the UNIX manual page document for
.\"                        pstojpeg.
.\"
.\"                        The checksum field above contains a CRC-16
.\"                        checksum as the first value, followed by the
.\"                        equivalent of the standard UNIX wc (word
.\"                        count) utility output of lines, words, and
.\"                        characters.  This is produced by Robert
.\"                        Solovay's checksum utility.",
.\"  }
.\" ====================================================================
.TH PSTOJPEG 1 "07 April 2001" "Version 1.00"
.if t .ds Ps P\s-2OST\s0S\s-2CRIPT\s0
.if n .ds Ps PostScript
.\"======================================================================
.SH NAME
pstojpeg \- convert (Encapsulated) PostScript files to JPEG bitmap files
.\"======================================================================
.SH SYNOPSIS
.B pstojpeg
[
.B \-?
]
[
.B \-crop
]
[
.B \-debug
]
[
.BI \-extension " name"
]
.if n .ti +9n
[
.BI \-gamma " float-value"
]
[
.B \-help
]
[
.B \-icon
]
.if n .ti +9n
.if t .ti +\w'\fBpstojpeg\fP\ 'u
[
.BI \-margin " pixels"
]
[
.B \-norun
]
.if n .ti +9n
[
.BI \-quality " percent-value"
]
.if n .ti +9n
[
.BI \-resolution " dpi"
]
[
.B \-version
]
.if n .ti +9n
.if t .ti +\w'\fBpstojpeg\fP\ 'u
[
.BI \-W "component,option"
]
.if n .ti +9n
.I "\*(Ps\&-files"
.\"======================================================================
.SH DESCRIPTION
.B pstojpeg
converts one or more input
.I "(Encapsulated) \*(Ps\&"
files to output
.I "Joint Photographic Experts Group (JPEG)"
lossy compressed bitmap files.
.PP
For maximal color fidelity, bitmaps are produced
in 24-bit color mode, with 16,777,216 possible
colors.
.PP
For each file given on the command line, an output
file is written with the same basename as the
input file, but with extension
.IR jpeg ,
or the name specified by the
.B \-extension
option.
.PP
With the
.B \-icon
option, small companion files with the same name
are also written in a subdirectory
.IR icons ,
which is created if necessary.
.PP
If no files are given on the command line, then
.I stdin
is read, and
.I stdout
is written, and no icon file can be produced.
.PP
.B pstojpeg
is a convenient interface to
.BR cjpeg (1),
.BR gs (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
and
.BR pngtopnm (1),
which do the real work.
.\"======================================================================
.SH OPTIONS
Command-line options may be abbreviated to a
unique leading prefix.
.PP
To avoid confusion with options, if a filename
begins with a hyphen, it must be disguised by a
leading absolute or relative directory path, e.g.
.I /tmp/-foo.eps
or
.IR ./-foo.eps .
.PP
Options may begin with either UNIX-style single
hyphens, or GNU/POSIX-style double hyphens, and
may be abbreviated to any unique prefix.
.\"-----------------------------------------------
.TP \w'\fB\-gamma\fP\ \fIfloat-value\fP'u+3n
.B \-crop
Crop the image to remove edges that are the
background color.
.\"-----------------------------------------------
.TP
.B \-debug
Turn on debug tracing.
.\"-----------------------------------------------
.TP
.BI \-extension " name"
Replace the default output file extension,
.IR xps ,
with
.IR name .
.\"-----------------------------------------------
.TP
.BI \-gamma " float-value"
Specify an image gamma correction as a
floating-point number.  Small values darken the
image, and large values lighten it.  Typical
values are in the range 0.5 .\|. 3.0.
.IP
.RI [Default: " 1.0" ]
.\"-----------------------------------------------
.TP
.B \-?
.br
.ns
.TP
.B \-help
Display a brief help message on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.B \-icon
Produce icon files as well as JPEG files.  An icon
file is just a low-resolution (12dpi) bitmap that
may be useful as a compact representation of what
is in the JPEG file.
.IP
In filter mode (no files on the command line),
this option is ignored.
.\"-----------------------------------------------
.TP
.BI \-margin " pixels"
Add a background margin of width
.I pixels
to the output image.  This option is usually
specified together with
.BR \-crop .
.\"-----------------------------------------------
.TP
.B \-norun
Show on
.I stdout
the commands that would be executed, but do not
run them.
.IP
Use this option to trap the complex command
pipelines for further private customization.
.\"-----------------------------------------------
.TP
.BI \-quality " percent-value"
Specify the JPEG quality parameter as a value in
0.\|.100.
.IP
Unlike the lossless PNG and TIFF bitmap formats,
the JPEG format is
.IR lossy ,
sacrificing quality to reduce data size.  A
quality value of 100 avoids quality loss, and
smaller values produce smaller files of lower
quality.
.IP
Warning: The JPEG format is suitable for
continuous tone images, such as digital
photographs, but introduces ghost artifacts in
regions of a single color, such as a solid
background in a line drawing.  The artifacts are
most evident at small quality values, and
disappear as the quality value is increased to
100.
.IP
.RI [Default: " 25" ]
.\"-----------------------------------------------
.TP
.BI \-resolution " dpi"
Set the output bitmap resolution to
.I dpi
dots per inch.
.IP
.RI [Default: " 100" " dpi, suitable only for screen resolution]."
.\"-----------------------------------------------
.TP
.B \-version
Display program version numbers and dates on
.IR stdout ,
and exit with a success status code (0 on UNIX).
.\"-----------------------------------------------
.TP
.BI \-W "component,option"
Pass
.I option
to the program
.IR component ,
which must be one of
.IR cjpeg ,
.IR gs ,
.IR pngtopnm ,
.IR pnmcrop ,
or
.IR pnmmargin .
.IP
This option, a POSIX convention, provides a
general way for a user to pass options to programs
invoked by another program.  The value
.I option
is passed
.I after
any generated in response to options supplied to
.BR pstojpeg .
For example,
.BI \-W pnmmargin,-black
would cause any added margin to be colored black.
.\"======================================================================
.SH "SEE ALSO"
.BR cjpeg (1),
.BR epsutil (1),
.BR gimp (1).
.BR gs (1),
.BR photoshop (1).
.BR pngtopnm (1),
.BR pnmcrop (1),
.BR pnmmargin (1),
.BR pstopng (1),
.BR pstotiff (1),
.BR xv (1).
.\"======================================================================
.SH AUTHOR
.nf
Nelson H. F. Beebe, Ph.D.
Center for Scientific Computing
University of Utah
Department of Mathematics, 322 INSCC
155 S 1400 E RM 233
Salt Lake City, UT 84112-0090
Tel: +1 801 581 5254
FAX: +1 801 585 1640, +1 801 581 4148
Email: \fCbeebe@math.utah.edu\fP, \fCbeebe@acm.org\fP,
       \fCbeebe@computer.org\fP, \fCbeebe@ieee.org\fP
WWW URL: \fChttp://www.math.utah.edu/~beebe\fP
.fi
.\"==============================[The End]==============================
.\" This is for GNU Emacs file-specific customization:
.\" Local Variables:
.\" fill-column: 50
.\" End:
